@@ -90,7 +90,7 @@ file-like objects:
 
 __ver_major__ = 0
 __ver_minor__ = 3
-__ver_patch__ = 6
+__ver_patch__ = 7
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 
@@ -252,7 +252,12 @@ class FileLikeBase(object):
 
         The file may not be accessed further once it is closed.
         """
-        if not getattr(self,"closed",False):
+        #  Errors in subclass constructors can cause this to be called without
+        #  having called FileLikeBase.__init__().  Since we need the attrs it
+        #  initialises in cleanup, ensure we call it here.
+        if not hasattr(self,"closed"):
+            FileLikeBase.__init__(self)
+        if not self.closed:
             self.flush()
             self.closed = True
 
@@ -474,7 +479,7 @@ class FileLikeBase(object):
         if self.closed:
             raise IOError("File has been closed")
         self._assert_mode("w-")
-        # If we were previusly reading, ensure position is correct
+        # If we were previously reading, ensure position is correct
         if self._rbuffer is not None:
             self.seek(0,1)
         # If we're actually behind the apparent position, we must also
