@@ -33,10 +33,7 @@ therefore optimise these operations.
 """ 
 
 import filelike
-from filelike.wrappers import FileWrapper
-
-import unittest
-from StringIO import StringIO
+from filelike.wrappers import FileWrapper, Debug
 
 
 class Translate(FileWrapper):
@@ -62,6 +59,8 @@ class Translate(FileWrapper):
     class instead; the efficiency of several operations can be improved
     dramatically given such properties of the translation function.
     """
+
+    _append_requires_overwrite = True
     
     def __init__(self,fileobj,rfunc=None,wfunc=None,mode=None):
         """Translate file wrapper constructor.
@@ -70,14 +69,15 @@ class Translate(FileWrapper):
         transformed, and 'rfunc' and 'wfunc' the callable objects that will
         transform the file's contents.
         """
-        super(Translate,self).__init__(fileobj,mode)
+        if mode is None:
+            mode = getattr(fileobj,"mode","r+")
         # rfunc must be provided for readable files
-        if self._check_mode("r-"):
+        if self._check_mode("r-",mode):
             if rfunc is None:
                 raise ValueError("Must provide 'rfunc' for readable files")
         # wfunc should be given for writable files, but we default to
         # using rfunc if it is specified.
-        if self._check_mode("w-"):
+        if self._check_mode("w-",mode):
             if wfunc is None:
                 if rfunc is None:
                     raise ValueError("Must provide 'wfunc' for writable files")
@@ -86,6 +86,7 @@ class Translate(FileWrapper):
         self._wfunc = self._normalise_func(wfunc)
         self._pos = 0
         self._read_eof = False
+        super(Translate,self).__init__(fileobj,mode)
 
     def _normalise_func(self,func):
         """Adjust a function to support flush() and reset() methods.
@@ -111,7 +112,14 @@ class Translate(FileWrapper):
         if data is not None:
             self._fileobj.write(data)
         super(Translate,self).flush()
-        self.seek(self.tell(),0)
+        if not self._closing:
+            if "-" not in self.mode:
+                self.seek(self.tell())
+            else:
+                if hasattr(self._rfunc,"reset"):
+                    self._rfunc.reset()
+                if hasattr(self._wfunc,"reset"):
+                    self._wfunc.reset()
 
     def _read(self,sizehint=-1):
         if self._read_eof:
@@ -150,16 +158,7 @@ class Translate(FileWrapper):
         if hasattr(self._wfunc,"reset"):
             self._wfunc.reset()
 
-
-class Test_Translate(filelike.Test_ReadWriteSeek):
-    """Testcases for the Translate class, with null translation func."""
-    
-    def makeFile(self,contents,mode):
-        def noop(string):
-            return string
-        return Translate(StringIO(contents),noop,mode=mode)
-
-    
+ 
 class BytewiseTranslate(FileWrapper):
     """Class implementing a bytewise translation on a file's contents.
     
@@ -200,13 +199,12 @@ class BytewiseTranslate(FileWrapper):
             self._rfunc = func
             self._wfunc = func
         else:
-            if hasattr(self,"mode"):
-              if "r" in self.mode or "+" in self.mode:
+            if self._check_mode("r-"):
                 if rfunc is None:
-                  raise ValueError("Must provide <rfunc> for readable files")
-              if "w" in self.mode or "a" in self.mode:
+                    raise ValueError("Must provide <rfunc> for readable files")
+            if self._check_mode("w-"):
                 if wfunc is None:
-                  raise ValueError("Must provide <wfunc> for writable files")
+                    raise ValueError("Must provide <wfunc> for writable files")
             self._rfunc = rfunc
             self._wfunc = wfunc
             
@@ -224,20 +222,3 @@ class BytewiseTranslate(FileWrapper):
     # Since this is a bytewise translation, the default seek() and tell()
     # will do what we want - simply move the underlying file object.
 
-
-class Test_BytewiseTranslate(filelike.Test_ReadWriteSeek):
-    """Testcases for the BytewiseTranslate class."""
-    
-    def makeFile(self,contents,mode):
-        def rot13(string):
-            return string.encode("rot13")
-        return BytewiseTranslate(StringIO(contents.encode("rot13")),rot13,mode=mode)
-
-
-
-def testsuite():
-    suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(Test_Translate))
-    suite.addTest(unittest.makeSuite(Test_BytewiseTranslate))
-    return suite
-
